/**
 * This program has been developed by a student from the bachelor Information Science at
 * Utrecht University within the Research Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

import { ViewModel, Command, GeoEdgeType, GeoGraphType } from '../types';

export class NodeLinkViewModel implements ViewModel {
  data: GeoGraphType;
  private original_data: GeoGraphType;

  constructor(data: any) {
    this.data = data;
    this.addCoordinatesToEdges();
    this.original_data = this.data;
  }

  executeCommand(command: Command) {
    this.data = command.execute(this.original_data);
  }

  addCoordinatesToEdges() {
    // Add coordinates to edges based on nodes
    const edges: { [key: string]: GeoEdgeType } = {};

    this.data.edges.forEach((edge: GeoEdgeType) => {
      const key = `${edge.from}_${edge.to}`;
      if (!edges[key]) {
        edges[key] = {
          ...edge,
          from_coordinates: this.data.nodes.find((node) => node.id === edge.from)?.attributes.coordinates,
          to_coordinates: this.data.nodes.find((node) => node.id === edge.to)?.attributes.coordinates,
          count: 1,
        };
      } else {
        edges[key].count++;
      }
    });

    this.data = {
      nodes: this.data.nodes,
      edges: Object.values(edges),
    };
  }

  resetGraph() {
    this.data = this.original_data;
  }

  getEdges() {
    return this.data.edges;
  }

  getNodes() {
    return this.data.nodes;
  }
}
